summaryrefslogtreecommitdiff
path: root/src/smi.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/smi.h')
-rw-r--r--src/smi.h19
1 files changed, 6 insertions, 13 deletions
diff --git a/src/smi.h b/src/smi.h
index 6012f76..4e0ef16 100644
--- a/src/smi.h
+++ b/src/smi.h
@@ -26,13 +26,11 @@ Silicon Motion shall not be used in advertising or otherwise to promote the
sale, use or other dealings in this Software without prior written
authorization from the XFree86 Project and Silicon Motion.
*/
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/siliconmotion/smi.h,v 1.13 2003/04/23 21:51:44 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/siliconmotion/smi.h,v 1.12tsi Exp $ */
#ifndef _SMI_H
#define _SMI_H
-#define USE_FB
-
#include "xf86.h"
#include "xf86_OSproc.h"
#include "xf86_ansic.h"
@@ -46,16 +44,7 @@ authorization from the XFree86 Project and Silicon Motion.
#include "mipointer.h"
#include "micmap.h"
-#ifdef USE_FB
#include "fb.h"
-#else
-
-#define PSZ 8
-#include "cfb.h"
-#undef PSZ
-#include "cfb16.h"
-#include "cfb24.h"
-#endif
#include "xaa.h"
#include "xf86cmap.h"
@@ -102,6 +91,7 @@ typedef struct
DPR44;
CARD32 VPR00, VPR0C, VPR10;
CARD32 CPR00;
+ CARD32 FPR00_, FPR0C_, FPR10_;
} SMIRegRec, *SMIRegPtr;
@@ -145,6 +135,7 @@ typedef struct
CARD8 * DPRBase; /* Base of DPR registers */
CARD8 * VPRBase; /* Base of VPR registers */
CARD8 * CPRBase; /* Base of CPR registers */
+ CARD8 * FPRBase; /* Base of FPR registers - for 0730 chipset */
CARD8 * DataPortBase; /* Base of data port */
int DataPortSize; /* Size of data port */
CARD8 * IOBase; /* Base of MMIO VGA ports */
@@ -225,7 +216,8 @@ typedef struct
pixels */
CARD32 saveBufferSize; /* #670 - FB save buffer size */
void * pSaveBuffer; /* #670 - FB save buffer */
- CARD32 savedFBOffset; /* #670 - Saved FBOffset value */
+ CARD32 fbMapOffset; /* offset for fb mapping */
+ CARD32 savedFBOffset; /* #670 - Saved FBOffset value */
CARD32 savedFBReserved; /* #670 - Saved
FBReserved value */
CARD8 * paletteBuffer; /* #920 - Palette save buffer */
@@ -351,6 +343,7 @@ Bool SMI_DGAInit(ScreenPtr pScrn);
/* smi_shadow.c */
void SMI_PointerMoved(int index, int x, int y);
void SMI_RefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
+void SMI_RefreshArea730(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
/* smi_video.c */
void SMI_InitVideo(ScreenPtr pScreen);